==> sugarcrm-2.5.1b_1.tbz: www/sugarcrm/modules/Versions/CheckVersions.php <==
<?PHP
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version
 * 1.1.3 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by SugarCRM" logo and
 *    (ii) the SugarCRM copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) 2004 SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
	//returns a list of components that are not of expected version
	function get_invalid_versions(){
		$invalid = array();
		
		require_once('modules/Versions/ExpectedVersions.php');
		require_once('modules/Versions/Version.php');
		foreach($expect_versions as $expect){
			$version = new Version();
			$valid = $version->retrieve_by_string_fields(array('name'=>$expect['name']));
			if($valid == null || ( !$version->is_expected_version($expect) && !empty($version->name) )){
				$invalid[$expect['name']] = $expect;
			}
		}
		return $invalid;
	}

?>

==> sugarcrm-3.5.1.tbz: www/sugarcrm/modules/Versions/CheckVersions.php <==
<?PHP
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version
 * 1.1.3 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by SugarCRM" logo and
 *    (ii) the SugarCRM copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) 2004-2005 SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
	//returns a list of components that are not of expected version
	function get_invalid_versions(){
		$invalid = array();
		
		require_once('modules/Versions/ExpectedVersions.php');
		require_once('modules/Versions/Version.php');
		foreach($expect_versions as $expect){
			$version = new Version();
			$result = $version->db->query("Select * from  $version->table_name  where  name='". $expect['name'] . "'");
			$valid = $version->db->fetchByAssoc($result);
			if($valid == null || ( !$version->is_expected_version($expect) && !empty($version->name) )){
		
				$invalid[$expect['name']] = $expect;
			}
		}
		return $invalid;
	}

?>
